@@ -18,7 +18,9 @@
 #include	<stdio.h>
 #include	<ctype.h>
 
-extern int errno;			/* only used in vt_write() */
+#define SEP_CHAR	' '		/* Separator bar character */
+
+extern int   errno;			/* only used in vt_write() */
 
 /* Function declarations */
 
@@ -79,6 +81,8 @@ int W_columns=0;	/* The number of columns per window */
 
 static int LU_lines;	/* A local copy of UU_lines that is modified */
 
+static char *termtype;
+
 /* A debugging routine */
 
 void vt_debug(debug)
@@ -116,7 +120,8 @@ char *init_vt100()
 	if ( ! isatty(0) || ! isatty(1) )
 		return("Standard input and output must be a tty");
 
-	if ( ((ptr=getenv("TERM")) == NULL || strncmp(ptr, "vt100", 5)) && 
+	if ( ((termtype=getenv("TERM")) == NULL || 
+         (strncmp(termtype, "vt100", 5)) != 0) && 
 			/* A vt100 emulation detector -->  */	! vttest() )
 		return("Terminal type must be set to vt100");
 
@@ -146,37 +151,33 @@ char *init_vt100()
 	/* Set the exportable variables */
 	if ( UU_lines ) {
 		/* Check the user set # of lines */
-		if ( UU_lines > (lines-3-3) )
-			LU_lines=(lines-3-3);
+		if ( UU_lines > (lines-1-3) )
+			LU_lines=(lines-1-3);
 		else if ( UU_lines < 3 )
 			LU_lines=3;
 		else
 			LU_lines=UU_lines;
 
 		WU_lines=LU_lines;
-		WL_lines=(lines-3-LU_lines);
+		WL_lines=(lines-1-LU_lines);
 	} else
-		WL_lines=WU_lines=((lines-3)/2);
+		WL_lines=WU_lines=((lines-1)/2);
 	W_columns=columns;
 
-
 	/* Set up the separator */
 	strcpy(sep, "\033[7m");
-	for ( i=0; (i<columns)&&(i<BUFSIZ); ++i )  sep[i+4]=' ';
+	for ( i=0; (i<columns)&&(i<BUFSIZ); ++i )  sep[i+4]=SEP_CHAR;
 	sep[i]='\0';
 	strcat(sep, "\033[m");
 
 	/* Clear the screen, and set up the windows */
 	CLEAR; 
-	printf("%s", sep);			/* Top line - separator */
-	ul_a=(1+1);				/* Upper limit of top win */
-	ll_a=(1+WU_lines);			/* Lower limit of top win */
-	vt_goto((1+WU_lines+1), 1);		/* Move past the top win */
-	printf("%s", sep);			/* Print separator */
-	ul_b=(1+WU_lines+1+1);			/* Upper limit of bottom win */
-	ll_b=(1+WU_lines+1+WL_lines);		/* Lower limit of bottom win */
-	vt_goto((1+WU_lines+1+WL_lines+1), 1);	/* Move past bottom win */
+	vt_goto((WU_lines+1), 1);		/* Move past the top win */
 	printf("%s", sep);			/* Print separator */
+	ul_a=(1);				/* Upper limit of top win */
+	ll_a=(WU_lines);			/* Lower limit of top win */
+	ul_b=(WU_lines+1+1);			/* Upper limit of bottom win */
+	ll_b=(WU_lines+1+WL_lines);		/* Lower limit of bottom win */
 	c_a.x=ul_a; c_a.y=1;			/* Set upper cursor */
 	c_b.x=ul_b; c_b.y=1;			/* Set lower cursor */
 	fflush(stdout);				/* Update the terminal */
@@ -612,7 +613,7 @@ char *prompt;
 
 	/* Save cursor position, go home, clear line and print prompt */
 	if ( prompt ) {
-		sprintf(format, "\0337\033[;H\033[K%%.%ds", columns);
+		sprintf(format, "\0337\033[%d;H\033[K%%.%ds", (WU_lines+1), columns);
 		printf(format, prompt);
 		fflush(stdout);
 	}
